<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:import href="Animal.xsl"/>
	<xsl:import href="Items.xsl"/>
	<xsl:import href="Skills.xsl"/>
	<xsl:import href="Feats.xsl"/>
	<xsl:import href="Spells Known.xsl"/>
	<xsl:import href="Spells Prepared.xsl"/>
	<xsl:import href="../Character/Stat Functions"/>
	<xsl:import href="../Character/General String Functions"/>
	<xsl:output method="html" indent="no" encoding="UTF-8"/>
	<xsl:template match="character">
		<font face="Courier" style="font-size:11pt">
			<b>
				<xsl:value-of select="name"/>
				<xsl:choose>
					<xsl:when test="gender != ''">
						<xsl:text>, </xsl:text>
						<xsl:value-of select="gender"/>
						<xsl:text> </xsl:text>
						<xsl:value-of select="race"/>
						<xsl:text> </xsl:text>
						<xsl:value-of select="classes/string"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="class"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="number(number) &gt; 1">
					<xsl:text> </xsl:text>(
					<xsl:value-of select="./number"/>)
				</xsl:if>
				<xsl:text>:</xsl:text>
			</b>
			<xsl:text> </xsl:text>
			<xsl:if test="challenge-rating != 0">
		CR 
				<xsl:value-of select="challenge-rating"/>;
			</xsl:if>
			<xsl:value-of select="size/category"/>
			<xsl:text> </xsl:text>
			<xsl:value-of select="size/type"/>
			<xsl:text> </xsl:text>
			<xsl:value-of select="size/subtype"/>;
			<xsl:text> </xsl:text>

	HD
			<xsl:text> </xsl:text>
			<xsl:for-each select="hit-dice/hit-die">
				<xsl:value-of select="die"/>
				<xsl:value-of select="bonus"/>
				<xsl:text>(</xsl:text>
				<xsl:value-of select="class"/>)
				<xsl:choose>
					<xsl:when test="position() = last()">
						<xsl:text>; </xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>, </xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>

	hp 
			<xsl:value-of select="hit-points"/>;
			<xsl:text> </xsl:text>
			<xsl:variable name="init" select="sum(initiative/modifiers/modifier[@name != 'misc']/@value)"/>
			<xsl:text>Init </xsl:text>
			<xsl:if test="$init >= 0">
				<xsl:text>+</xsl:text>
			</xsl:if>
			<xsl:value-of select="$init"/>;
			<xsl:text> </xsl:text>
			<xsl:text>Spd </xsl:text>
			<xsl:for-each select="speeds/speed">
				<xsl:if test="position() &gt; 1">
					<xsl:text>, </xsl:text>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="name = 'Base'">
						<xsl:value-of select="value"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="name"/>
						<xsl:text> </xsl:text>
						<xsl:value-of select="value"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="position() = last()">
					<xsl:text>; </xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>AC:</xsl:text>
			<xsl:call-template name="AC">
				<xsl:with-param name="AC-mods" select="//character/armor-class/modifiers"/>
			</xsl:call-template>
			<xsl:text> (Flatfooted:</xsl:text>
			<xsl:call-template name="AC-flat-footed">
				<xsl:with-param name="AC-mods" select="//character/armor-class/modifiers"/>
				<xsl:with-param name="all-class-features" select="//character/features/class-features//feature"/>
			</xsl:call-template>
			<xsl:text> </xsl:text>
			<xsl:text>Touch:</xsl:text>
			<xsl:call-template name="AC-touch">
				<xsl:with-param name="AC-mods" select="//character/armor-class/modifiers"/>
			</xsl:call-template>
			<xsl:text>); </xsl:text>
			<xsl:text>Atk </xsl:text>
			<xsl:variable name="bab1" select="/character/attacks/base"/>
			<xsl:variable name="bab2" select="substring($bab1,2) - 5"/>
			<xsl:variable name="bab3" select="substring($bab1,2) - 10"/>
			<xsl:variable name="bab4" select="substring($bab1,2) - 15"/>
			<xsl:variable name="meleetotal" select="sum(attacks/melee/modifiers/modifier[@name != 'misc']/@value)"/>
			<xsl:variable name="melee2" select="$meleetotal - 5"/>
			<xsl:variable name="melee3" select="$meleetotal - 10"/>
			<xsl:variable name="melee4" select="$meleetotal - 15"/>
			<xsl:text>+</xsl:text>
			<xsl:value-of select="$meleetotal"/>
			<xsl:if test="$bab2 > 0">
				<xsl:text>/</xsl:text>
				<xsl:value-of select="$melee2"/>
			</xsl:if>
			<xsl:if test="$bab3 > 0">
				<xsl:text>/</xsl:text>
				<xsl:value-of select="$melee3"/>
			</xsl:if>
			<xsl:if test="$bab4 > 0">
				<xsl:text>/</xsl:text>
				<xsl:value-of select="$melee4"/>
			</xsl:if>
			<xsl:text> base melee, </xsl:text>
			<xsl:variable name="rangetotal" select="sum(attacks/ranged/modifiers/modifier[@name != 'misc']/@value)"/>
			<xsl:variable name="range2" select="$rangetotal - 5"/>
			<xsl:variable name="range3" select="$rangetotal - 10"/>
			<xsl:variable name="range4" select="$rangetotal - 15"/>
			<xsl:text>+</xsl:text>
			<xsl:value-of select="$rangetotal"/>
			<xsl:if test="$bab2 > 0">
				<xsl:text>/</xsl:text>
				<xsl:value-of select="$range2"/>
			</xsl:if>
			<xsl:if test="$bab3 > 0">
				<xsl:text>/</xsl:text>
				<xsl:value-of select="$range3"/>
			</xsl:if>
			<xsl:if test="$bab4 > 0">
				<xsl:text>/</xsl:text>
				<xsl:value-of select="$range4"/>
			</xsl:if>
			<xsl:text> base ranged; </xsl:text>
			<xsl:for-each select="equiped-items/weapons">
				<xsl:for-each select="weapon">
					<xsl:variable name="basebonus1" select="/character/attacks/base"/>
					<xsl:variable name="basebonus2" select="substring($basebonus1,2) - 5"/>
					<xsl:variable name="basebonus3" select="substring($basebonus1,2) - 10"/>
					<xsl:variable name="basebonus4" select="substring($basebonus1,2) - 15"/>
					<xsl:variable name="basemonk2" select="substring($basebonus1,2) - 3"/>
					<xsl:variable name="basemonk3" select="substring($basebonus1,2) - 6"/>
					<xsl:variable name="basemonk4" select="substring($basebonus1,2) - 9"/>
					<xsl:variable name="basemonk5" select="substring($basebonus1,2) - 12"/>
					<xsl:variable name="basemonk6" select="substring($basebonus1,2) - 15"/>
					<xsl:variable name="tmpbonus1" select="bonus"/>
					<xsl:variable name="tmpbonus2" select="substring($tmpbonus1,2) - 5"/>
					<xsl:variable name="tmpbonus3" select="substring($tmpbonus1,2) - 10"/>
					<xsl:variable name="tmpbonus4" select="substring($tmpbonus1,2) - 15"/>
					<xsl:variable name="mnkbonus2" select="substring($tmpbonus1,2) - 3"/>
					<xsl:variable name="mnkbonus3" select="substring($tmpbonus1,2) - 6"/>
					<xsl:variable name="mnkbonus4" select="substring($tmpbonus1,2) - 9"/>
					<xsl:variable name="mnkbonus5" select="substring($tmpbonus1,2) - 12"/>
					<xsl:variable name="mnkbonus6" select="substring($tmpbonus1,2) - 15"/>
					<xsl:value-of select="$tmpbonus1"/>
					<xsl:if test="position() = 1">
						<xsl:choose>
							<xsl:when test="name = 'Unarmed' or name = 'Kama' or name = 'Nunchaku' or name = 'Siangham'">
								<xsl:for-each select="/character/classes/class">
									<xsl:if test="name = 'Monk'">
										<xsl:if test="$basemonk2 > 0">
											<xsl:text>/</xsl:text>
											<xsl:value-of select="$mnkbonus2"/>
										</xsl:if>
										<xsl:if test="$basemonk3 > 0">
											<xsl:text>/</xsl:text>
											<xsl:value-of select="$mnkbonus3"/>
										</xsl:if>
										<xsl:if test="$basemonk4 > 0">
											<xsl:text>/</xsl:text>
											<xsl:value-of select="$mnkbonus4"/>
										</xsl:if>
										<xsl:if test="$basemonk5 > 0">
											<xsl:text>/</xsl:text>
											<xsl:value-of select="$mnkbonus5"/>
										</xsl:if>
										<xsl:if test="$basemonk6 > 0">
											<xsl:text>/</xsl:text>
											<xsl:value-of select="$mnkbonus6"/>
										</xsl:if>
									</xsl:if>
								</xsl:for-each>
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="use-type != 'Double'">
									<xsl:if test="$basebonus2 > 0">
										<xsl:text>/</xsl:text>
										<xsl:value-of select="$tmpbonus2"/>
									</xsl:if>
									<xsl:if test="$basebonus3 > 0">
										<xsl:text>/</xsl:text>
										<xsl:value-of select="$tmpbonus3"/>
									</xsl:if>
									<xsl:if test="$basebonus4 > 0">
										<xsl:text>/</xsl:text>
										<xsl:value-of select="$tmpbonus4"/>
									</xsl:if>
								</xsl:if>
								<xsl:if test="use-type = 'Double'">
									<xsl:if test="substring(bonus, 4, 1) = '/'">
										<xsl:if test="$basebonus2 > 0">
											<xsl:text>/</xsl:text>
											<xsl:value-of select="substring(bonus, 2, 2) - 5"/>
										</xsl:if>
										<xsl:if test="$basebonus3 > 0">
											<xsl:text>/</xsl:text>
											<xsl:value-of select="substring(bonus, 2, 2) - 10"/>
										</xsl:if>
										<xsl:if test="$basebonus4 > 0">
											<xsl:text>/</xsl:text>
											<xsl:value-of select="substring(bonus, 2, 2) - 15"/>
										</xsl:if>
									</xsl:if>
									<xsl:if test="substring(bonus, 3, 1) = '/'">
										<xsl:if test="$basebonus2 > 0">
											<xsl:text>/</xsl:text>
											<xsl:value-of select="substring(bonus, 2, 1) - 5"/>
										</xsl:if>
										<xsl:if test="$basebonus3 > 0">
											<xsl:text>/</xsl:text>
											<xsl:value-of select="substring(bonus, 2, 1) - 10"/>
										</xsl:if>
										<xsl:if test="$basebonus4 > 0">
											<xsl:text>/</xsl:text>
											<xsl:value-of select="substring(bonus, 2, 1) - 15"/>
										</xsl:if>
									</xsl:if>
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>
					<xsl:if test="position() > 1">
						<xsl:for-each select="//character/features/feats/feat">
							<xsl:if test="name = 'Improved Two-Weapon Fighting'">
								<xsl:if test="$basebonus2 > 0">
									<xsl:text>/</xsl:text>
									<xsl:value-of select="$tmpbonus2"/>
								</xsl:if>
							</xsl:if>
						</xsl:for-each>
					</xsl:if>
					<!--			<xsl:value-of select="bonus"/>  -->
					<xsl:choose>
						<xsl:when test="position() = last()"></xsl:when>
						<xsl:otherwise>
							<xsl:text>/</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
				<xsl:text> (</xsl:text>
				<xsl:for-each select="weapon">
					<xsl:value-of select="damage"/>, 
					<xsl:value-of select="name"/>
					<xsl:choose>
						<xsl:when test="position() = last()"></xsl:when>
						<xsl:otherwise>
							<xsl:text>; </xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
				<xsl:text>);</xsl:text>
				<xsl:text> </xsl:text>
			</xsl:for-each>
			<xsl:for-each select="features/special-attacks/special-attack">
				<xsl:if test="position() = 1">
					<xsl:text>SA: </xsl:text>
				</xsl:if>
				<xsl:value-of select="."/>
				<xsl:choose>
					<xsl:when test="position() = last()">
						<xsl:text>; </xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>, </xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			<xsl:for-each select="features/special-qualities/special-quality">
				<xsl:if test="position() = 1">
					<xsl:text>SQ: </xsl:text>
				</xsl:if>
				<xsl:value-of select="."/>
				<xsl:choose>
					<xsl:when test="position() = last()">
						<xsl:text>; </xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>, </xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			<xsl:for-each select="features/race-features/race-feature">
				<xsl:if test="position() = 1">
					<xsl:text>RF: </xsl:text>
				</xsl:if>
				<xsl:value-of select="."/>
				<xsl:choose>
					<xsl:when test="position() = last()">
						<xsl:text>; </xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>, </xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			<xsl:if test="spell-resistance != ''">
		SR 
				<xsl:value-of select="spell-resistance"/>;
				<xsl:text> </xsl:text>
			</xsl:if>

	AL 
			<xsl:value-of select="alignment/abbr"/>;
			<xsl:text> </xsl:text>
			<xsl:text>SV </xsl:text>
			<xsl:for-each select="saving-throws/saving-throw">
				<xsl:value-of select="abbr"/>
				<xsl:text> </xsl:text>
				<xsl:variable name="save" select="sum(modifiers/modifier[@name != 'misc']/@value)"/>
				<xsl:if test="$save >= 0">
					<xsl:text>+</xsl:text>
				</xsl:if>
				<xsl:value-of select="$save"/>
				<xsl:choose>
					<xsl:when test="position() = last()">
						<xsl:text>; </xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>, </xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			<xsl:for-each select="abilities/ability">
				<xsl:value-of select="abbr"/>
				<xsl:text> </xsl:text>
				<xsl:value-of select="base"/>
				<xsl:choose>
					<xsl:when test="position() = last()">
						<xsl:text>.</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>, </xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			<xsl:apply-templates select="skills"/>
			<br/>
			<xsl:apply-templates select="features/feats"/>
			<br/>
			<xsl:apply-templates select="spells-known"/>
			<xsl:apply-templates select="spells-prepared"/>
			<xsl:if test="count(items/item) > 0">
				<b>Possessions:</b>
				<xsl:text> </xsl:text>
			</xsl:if>
			<xsl:apply-templates select="items"/>
			<br/>
			<xsl:for-each select="animals/animal">
				<xsl:apply-templates select="."/>
				<br/>
			</xsl:for-each>
			<br/>
		</font>
	</xsl:template>
</xsl:stylesheet>